@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 1999, 2019, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -37,25 +37,27 @@ class VersionProps {
         "openjdk";
 
     private static final String java_version =
-        "13.0.2";
+        "14.0.1";
 
     private static final String java_version_date =
-        "2020-01-14";
+        "2020-04-14";
 
+    // This field is read by HotSpot
     private static final String java_runtime_name =
         "OpenJDK Runtime Environment";
 
+    // This field is read by HotSpot
     private static final String java_runtime_version =
-        "13.0.2+8";
+        "14.0.1+7";
 
     private static final String VERSION_NUMBER =
-        "13.0.2";
+        "14.0.1";
 
     private static final String VERSION_SPECIFICATION =
-        "13";
+        "14";
 
     private static final String VERSION_BUILD =
-        "8";
+        "7";
 
     private static final String VERSION_PRE =
         "";
@@ -67,14 +69,7 @@ class VersionProps {
         "".startsWith("LTS");
 
     private static final String CLASSFILE_MAJOR_MINOR =
-        "57.0";
-
-    private static final String VENDOR_VERSION_STRING =
-        "";
-
-    private static final String vendor_version =
-        (!VENDOR_VERSION_STRING.isEmpty()
-         ? " " + VENDOR_VERSION_STRING : "");
+        "58.0";
 
     private static final String VENDOR =
         "N/A";
@@ -82,9 +77,20 @@ class VersionProps {
     private static final String VENDOR_URL =
         "https://openjdk.java.net/";
 
-    private static final String VENDOR_URL_BUG =
+    // The remaining VENDOR_* fields must not be final,
+    // so that they can be redefined by jlink plugins
+
+    // This field is read by HotSpot
+    private static String VENDOR_VERSION =
+        "";
+
+    private static String VENDOR_URL_BUG =
         "https://bugreport.java.com/bugreport/";
 
+    // This field is read by HotSpot
+    private static String VENDOR_URL_VM_BUG =
+        "https://bugreport.java.com/bugreport/crash.jsp";
+
     /**
      * Initialize system properties using build provided values.
      *
@@ -95,8 +101,8 @@ class VersionProps {
         props.put("java.version.date", java_version_date);
         props.put("java.runtime.version", java_runtime_version);
         props.put("java.runtime.name", java_runtime_name);
-        if (!VENDOR_VERSION_STRING.isEmpty())
-            props.put("java.vendor.version", VENDOR_VERSION_STRING);
+        if (!VENDOR_VERSION.isEmpty())
+            props.put("java.vendor.version", VENDOR_VERSION);
 
         props.put("java.class.version", CLASSFILE_MAJOR_MINOR);
 
@@ -216,6 +222,9 @@ class VersionProps {
             jdk_debug_level = jdk_debug_level + " ";
         }
 
+        String vendor_version = (VENDOR_VERSION.isEmpty()
+                                 ? "" : " " + VENDOR_VERSION);
+
         ps.println(java_runtime_name + vendor_version
                    + " (" + jdk_debug_level + "build " + java_runtime_version + ")");
 
