@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -170,7 +170,7 @@ public class FormatData_hu extends ListResourceBundle {
                "H:mm:ss",
                "H:mm",
             };
-        final String[] metaValue_buddhist_long_Eras = new String[] {
+        final String[] metaValue_java_time_buddhist_long_Eras = new String[] {
                "BC",
                "BK",
             };
@@ -186,11 +186,11 @@ public class FormatData_hu extends ListResourceBundle {
                "GGGG y. MMM d.",
                "G y. M. d.",
             };
-        final String[] metaValue_roc_long_Eras = new String[] {
+        final String[] metaValue_java_time_roc_long_Eras = new String[] {
                "R.O.C. el\u0151tt",
                "R.O.C.",
             };
-        final String[] metaValue_islamic_long_Eras = new String[] {
+        final String[] metaValue_java_time_islamic_long_Eras = new String[] {
                "",
                "MF",
             };
@@ -200,7 +200,7 @@ public class FormatData_hu extends ListResourceBundle {
             { "field.year", "\u00e9v" },
             { "calendarname.islamic-umalqura", "Iszl\u00e1m Umm al-Qura napt\u00e1r" },
             { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.narrow.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.japanese.DatePatterns",
                 new String[] {
@@ -223,7 +223,7 @@ public class FormatData_hu extends ListResourceBundle {
             { "calendarname.islamic-civil", "Iszl\u00e1m civil napt\u00e1r" },
             { "islamic.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_TimePatterns },
-            { "roc.long.Eras", metaValue_roc_long_Eras },
+            { "roc.long.Eras", metaValue_java_time_roc_long_Eras },
             { "narrow.Eras",
                 new String[] {
                     "ie.",
@@ -237,6 +237,7 @@ public class FormatData_hu extends ListResourceBundle {
             { "japanese.MonthNames", metaValue_MonthNames },
             { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
+            { "java.time.islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "long.Eras",
                 new String[] {
                     "Krisztus el\u0151tt",
@@ -307,21 +308,33 @@ public class FormatData_hu extends ListResourceBundle {
             { "calendarname.roc", "K\u00ednai k\u00f6zt\u00e1rsas\u00e1gi napt\u00e1r" },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "islamic.Eras", metaValue_islamic_long_Eras },
+            { "islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "field.month", "h\u00f3nap" },
-            { "roc.Eras", metaValue_roc_long_Eras },
+            { "roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.second", "m\u00e1sodperc" },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNarrows", metaValue_DayNarrows },
-            { "NumberPatterns",
+            { "islamic.MonthNarrows",
                 new String[] {
-                    "#,##0.###",
-                    "#,##0.00\u00a0\u00a4",
-                    "#,##0%",
+                    "1",
+                    "2",
+                    "3",
+                    "4",
+                    "5",
+                    "6",
+                    "7",
+                    "8",
+                    "9",
+                    "10",
+                    "11",
+                    "12",
+                    "",
                 }
             },
+            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayNarrows", metaValue_DayNarrows },
             { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "calendarname.islamic", "Iszl\u00e1m napt\u00e1r" },
+            { "java.time.roc.long.Eras", metaValue_java_time_roc_long_Eras },
+            { "java.time.roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "japanese.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
@@ -331,18 +344,18 @@ public class FormatData_hu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0 ezer",
-                    "00 ezer",
-                    "000 ezer",
-                    "0 milli\u00f3",
-                    "00 milli\u00f3",
-                    "000 milli\u00f3",
-                    "0 milli\u00e1rd",
-                    "00 milli\u00e1rd",
-                    "000 milli\u00e1rd",
-                    "0 billi\u00f3",
-                    "00 billi\u00f3",
-                    "000 billi\u00f3",
+                    "{one:0' 'ezer other:0' 'ezer}",
+                    "{one:00' 'ezer other:00' 'ezer}",
+                    "{one:000' 'ezer other:000' 'ezer}",
+                    "{one:0' 'milli\u00f3 other:0' 'milli\u00f3}",
+                    "{one:00' 'milli\u00f3 other:00' 'milli\u00f3}",
+                    "{one:000' 'milli\u00f3 other:000' 'milli\u00f3}",
+                    "{one:0' 'milli\u00e1rd other:0' 'milli\u00e1rd}",
+                    "{one:00' 'milli\u00e1rd other:00' 'milli\u00e1rd}",
+                    "{one:000' 'milli\u00e1rd other:000' 'milli\u00e1rd}",
+                    "{one:0' 'billi\u00f3 other:0' 'billi\u00f3}",
+                    "{one:00' 'billi\u00f3 other:00' 'billi\u00f3}",
+                    "{one:000' 'billi\u00f3 other:000' 'billi\u00f3}",
                 }
             },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
@@ -359,13 +372,15 @@ public class FormatData_hu extends ListResourceBundle {
             { "islamic.QuarterAbbreviations", metaValue_QuarterAbbreviations },
             { "roc.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.DayNarrows", metaValue_DayNarrows },
+            { "java.time.buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.long.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.long.Eras", metaValue_java_time_buddhist_long_Eras },
             { "TimePatterns", metaValue_TimePatterns },
             { "islamic.DayNarrows", metaValue_DayNarrows },
+            { "java.time.roc.Eras", metaValue_java_time_roc_long_Eras },
             { "field.zone", "id\u0151z\u00f3na" },
             { "japanese.QuarterAbbreviations", metaValue_QuarterAbbreviations },
-            { "roc.narrow.Eras", metaValue_roc_long_Eras },
+            { "roc.narrow.Eras", metaValue_java_time_roc_long_Eras },
             { "buddhist.narrow.AmPmMarkers", metaValue_AmPmMarkers },
             { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
             { "Eras",
@@ -390,15 +405,17 @@ public class FormatData_hu extends ListResourceBundle {
             { "field.weekday", "h\u00e9t napja" },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
             { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.long.Eras", metaValue_islamic_long_Eras },
+            { "islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
+            { "java.time.islamic.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.QuarterNames", metaValue_QuarterNames },
             { "buddhist.QuarterAbbreviations", metaValue_QuarterAbbreviations },
+            { "java.time.buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "japanese.DayNames", metaValue_DayNames },
             { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
             { "DayNames", metaValue_DayNames },
             { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "buddhist.Eras", metaValue_buddhist_long_Eras },
+            { "buddhist.Eras", metaValue_java_time_buddhist_long_Eras },
             { "field.week", "h\u00e9t" },
             { "buddhist.MonthNarrows", metaValue_MonthNarrows },
             { "buddhist.QuarterNames", metaValue_QuarterNames },
@@ -412,21 +429,22 @@ public class FormatData_hu extends ListResourceBundle {
                     "",
                     "",
                     "",
-                    "0\u00a0E",
-                    "00\u00a0E",
-                    "000\u00a0E",
-                    "0\u00a0M",
-                    "00\u00a0M",
-                    "000\u00a0M",
-                    "0\u00a0Mrd",
-                    "00\u00a0Mrd",
-                    "000\u00a0Mrd",
-                    "0\u00a0B",
-                    "00\u00a0B",
-                    "000\u00a0B",
+                    "{one:0\u00a0E other:0\u00a0E}",
+                    "{one:00\u00a0E other:00\u00a0E}",
+                    "{one:000\u00a0E other:000\u00a0E}",
+                    "{one:0\u00a0M other:0\u00a0M}",
+                    "{one:00\u00a0M other:00\u00a0M}",
+                    "{one:000\u00a0M other:000\u00a0M}",
+                    "{one:0\u00a0Mrd other:0\u00a0Mrd}",
+                    "{one:00\u00a0Mrd other:00\u00a0Mrd}",
+                    "{one:000\u00a0Mrd other:000\u00a0Mrd}",
+                    "{one:0\u00a0B other:0\u00a0B}",
+                    "{one:00\u00a0B other:00\u00a0B}",
+                    "{one:000\u00a0B other:000\u00a0B}",
                 }
             },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
+            { "java.time.buddhist.narrow.Eras", metaValue_java_time_buddhist_long_Eras },
             { "timezone.regionFormat.daylight", "{0} ny\u00e1ri id\u0151" },
             { "DatePatterns",
                 new String[] {
@@ -458,10 +476,19 @@ public class FormatData_hu extends ListResourceBundle {
                     "",
                 }
             },
-            { "islamic.narrow.Eras", metaValue_islamic_long_Eras },
+            { "islamic.narrow.Eras", metaValue_java_time_islamic_long_Eras },
             { "calendarname.buddhist", "Buddhista napt\u00e1r" },
             { "standalone.MonthNames", metaValue_MonthNames },
+            { "latn.NumberPatterns",
+                new String[] {
+                    "#,##0.###",
+                    "#,##0.00\u00a0\u00a4",
+                    "#,##0%",
+                    "#,##0.00\u00a0\u00a4",
+                }
+            },
             { "buddhist.DayNarrows", metaValue_DayNarrows },
+            { "java.time.islamic.long.Eras", metaValue_java_time_islamic_long_Eras },
             { "japanese.DayNarrows", metaValue_DayNarrows },
             { "QuarterNames", metaValue_QuarterNames },
             { "roc.TimePatterns", metaValue_TimePatterns },
