@@ -128,6 +128,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
             { "tem", "temne" },
+            { "Medf", "medefaidrin" },
             { "type.nu.sind", "khudawidiska siffror" },
             { "teo", "teso" },
             { "rap", "rapanui" },
@@ -193,6 +194,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "BZ", "Belize" },
             { "Visp", "synligt tal" },
             { "type.ca.persian", "persisk kalender" },
+            { "%%CREISS", "croissant-occitanska" },
             { "type.nu.hebr", "hebreiska taltecken" },
             { "CA", "Kanada" },
             { "CC", "Kokos\u00f6arna" },
@@ -201,7 +203,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "CF", "Centralafrikanska republiken" },
             { "CG", "Kongo-Brazzaville" },
             { "CH", "Schweiz" },
-            { "CI", "Elfenbenskusten" },
+            { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Cook\u00f6arna" },
             { "CL", "Chile" },
             { "Kthi", "kaithiska" },
@@ -333,6 +335,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "zxx", "inget spr\u00e5kligt inneh\u00e5ll" },
             { "Jurc", "jurchenska" },
             { "tly", "talysh" },
+            { "%%VIVARAUP", "vivaroalpinska (occitanska)" },
             { "pdt", "mennonitisk l\u00e5gtyska" },
             { "de_AT", "\u00f6sterrikisk tyska" },
             { "Vaii", metaValue_vai },
@@ -486,6 +489,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "MZ", "Mo\u00e7ambique" },
             { "Phli", "tidig pahlavi" },
             { "NA", "Namibia" },
+            { "%%ARANES", "aranesiska (occitanska)" },
             { "202", "Subsahariska Afrika" },
             { "type.ca.hebrew", "hebreisk kalender" },
             { "type.co.dictionary", "ordbokssorteringsordning" },
@@ -516,6 +520,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Mero", "meroitiska" },
             { "crh", "krimtatariska" },
             { "ang", "fornengelska" },
+            { "%%GRMISTR", "Mistral-occitanska" },
             { "OM", "Oman" },
             { "%%PETR1708", "1708 \u00e5rs stavning" },
             { "anp", "angika" },
@@ -533,6 +538,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "PG", "Papua Nya Guinea" },
             { "PH", "Filippinerna" },
             { "PK", "Pakistan" },
+            { "%%NICARD", "Nice-occitanska" },
             { "PL", "Polen" },
             { "ewo", "ewondo" },
             { "PM", "S:t Pierre och Miquelon" },
@@ -561,6 +567,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "tvl", "tuvaluanska" },
             { "Tavt", "tai viet" },
             { "%%SOTAV", "sotavento-dialekt" },
+            { "Maka", "makasariska" },
             { "001", "v\u00e4rlden" },
             { "002", "Afrika" },
             { "njo", "ao-naga" },
@@ -702,6 +709,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "VE", "Venezuela" },
             { "VG", "Brittiska Jungfru\u00f6arna" },
             { "VI", "Amerikanska Jungfru\u00f6arna" },
+            { "%%LEMOSIN", "Limousin-occitanska" },
             { "Soyo", "soyombo" },
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
@@ -775,7 +783,10 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.nu.telu", "telugiska siffror" },
             { "lou", "louisiana-kreol" },
             { "loz", "lozi" },
+            { "%%FONKIRSH", "Kirshenbaums fonetiska alfabet" },
             { "Nkgb", "naxi geba" },
+            { "%%ASANTE", "asante (twi)" },
+            { "%%AUVERN", "auvergniska (occitanska)" },
             { "jmc", "kimashami" },
             { "hif", "Fiji-hindi" },
             { "type.nu.hansfin", "f\u00f6renklat kinesiskt finansiellt stavade tal" },
@@ -794,6 +805,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "nwc", "klassisk newariska" },
             { "udm", "udmurtiska" },
             { "Khmr", "khmeriska" },
+            { "%%FONNAPA", "nordamerikanskt fonetiskt alfabet" },
             { "type.ca.islamic-rgsa", "islamisk kalender, Saudi-Arabien" },
             { "Limb", "limbu" },
             { "sad", "sandawe" },
@@ -821,6 +833,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.d0.fwidth", "till helbreda" },
             { "sbp", "sangu" },
             { "lui", "luise\u00f1o" },
+            { "%%GRITAL", "italiensk-inspirerad occitanska" },
             { "nyn", "nyankole" },
             { "nym", "nyamwezi" },
             { "lun", "lunda" },
@@ -871,6 +884,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "az", "azerbajdzjanska" },
             { "Rohg", "hanifiska" },
             { "Khoj", "khojkiska" },
+            { "%%CISAUP", "cisalpinska (occitanska)" },
             { "%%OSOJS", "Osojane-dialekt" },
             { "%%UNIFON", "unifon-skrift" },
             { "ba", "basjkiriska" },
@@ -894,7 +908,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Nkoo", metaValue_nqo },
             { "sel", "selkup" },
             { "ca", "katalanska" },
-            { "ses", "Gao-songhay" },
+            { "ses", "Gao-songhai" },
             { "ce", "tjetjenska" },
             { "ch", "chamorro" },
             { "%%REVISED", "reformerad stavning" },
@@ -969,6 +983,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.m0.bgn", "enligt USA:s geografiska namnkommitt\u00e9" },
             { "umb", "umbundu" },
             { "fr", "franska" },
+            { "%%AKUAPEM", "akapuem (twi)" },
             { "sid", "sidamo" },
             { "fy", "v\u00e4stfrisiska" },
             { "ga", "iriska" },
@@ -1004,6 +1019,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "id", "indonesiska" },
             { "type.nu.tibt", "tibetanska siffror" },
             { "ie", "interlingue" },
+            { "%%GASCON", "Gascogne-occitanska" },
             { "ig", "igbo" },
             { "ii", "szezuan i" },
             { "frm", "medelfranska" },
@@ -1064,7 +1080,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "ku", "kurdiska" },
             { "kv", "kome" },
             { "kw", "korniska" },
-            { "ky", "kirgisiska" },
+            { "ky", "kirgiziska" },
             { "snk", "soninke" },
             { "Mult", "multaniska" },
             { "la", "latin" },
@@ -1111,6 +1127,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "nl", "nederl\u00e4ndska" },
             { "nn", "nynorska" },
             { "no", "norska" },
+            { "%%PROVENC", "provensalska" },
             { "nr", "sydndebele" },
             { "type.nu.modi", "modi-siffror" },
             { "Osge", metaValue_osa },
@@ -1292,7 +1309,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "type.ca.roc", "kinesiska republikens kalender" },
             { "vi", "vietnamesiska" },
             { "kho", "khotanesiska" },
-            { "khq", "Timbuktu-songhoy" },
+            { "khq", "Timbuktu-songhai" },
             { "key.hc", "12- eller 24-timmarsklocka" },
             { "%%TARASK", "Taraskievika-stavning" },
             { "vo", "volap\u00fck" },
@@ -1335,6 +1352,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "xh", "xhosa" },
             { "type.nu.romanlow", "sm\u00e5 romerska taltecken" },
             { "byn", "blin" },
+            { "Dogr", "dogriska" },
             { "%%PAMAKA", "Pamaka-dialekt" },
             { "Lyci", "lykiska" },
             { "osa", metaValue_osa },
@@ -1368,6 +1386,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "%%MONOTON", "monotonisk stavning" },
             { "Geor", metaValue_ka },
             { "Shrd", "sharada" },
+            { "%%LENGADOC", "languedociska" },
             { "kmb", "kimbundu" },
             { "type.nu.jpanfin", "japanskt finansiellt stavade tal" },
             { "Cham", "cham" },
@@ -1402,6 +1421,7 @@ public class LocaleNames_sv extends OpenListResourceBundle {
             { "Sund", metaValue_su },
             { "vep", "veps" },
             { "kpe", "kpelle" },
+            { "%%GRCLASS", "klassisk occitanska" },
             { "type.nu.khmr", "khmeriska siffror" },
             { "Tirh", "tirhuta" },
             { "ilo", "iloko" },
