@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "Falklandsk\u00fd \u010das",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "Bh\u00fat\u00e1nsk\u00fd \u010das",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Apijsk\u00fd standardn\u00ed \u010das",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "Apijsk\u00fd \u010das",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "Bh\u00fat\u00e1nsk\u00fd \u010das",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "Naursk\u00fd \u010das",
                "",
@@ -439,7 +439,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "",
             };
         final String[] Norfolk = new String[] {
-               "Norfolsk\u00fd \u010das",
+               "Norfolksk\u00fd \u010das",
                "",
                "",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Kolumbijsk\u00fd standardn\u00ed \u010das",
+        final String[] Australia_Eastern = new String[] {
+               "V\u00fdchodoaustralsk\u00fd standardn\u00ed \u010das",
                "",
-               "Kolumbijsk\u00fd letn\u00ed \u010das",
+               "V\u00fdchodoaustralsk\u00fd letn\u00ed \u010das",
                "",
-               "Kolumbijsk\u00fd \u010das",
+               "V\u00fdchodoaustralsk\u00fd \u010das",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "V\u00fdchodoaustralsk\u00fd standardn\u00ed \u010das",
+        final String[] Colombia = new String[] {
+               "Kolumbijsk\u00fd standardn\u00ed \u010das",
                "",
-               "V\u00fdchodoaustralsk\u00fd letn\u00ed \u010das",
+               "Kolumbijsk\u00fd letn\u00ed \u010das",
                "",
-               "V\u00fdchodoaustralsk\u00fd \u010das",
+               "Kolumbijsk\u00fd \u010das",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,14 +710,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "Paraguaysk\u00fd \u010das",
                "",
             };
-        final String[] Casey = new String[] {
-               "\u010cas Caseyho stanice",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "Malajsk\u00fd \u010das",
                "",
@@ -999,7 +991,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "",
             };
         final String[] Pitcairn = new String[] {
-               "\u010cas Pitcairnova ostrova",
+               "\u010cas Pitcairnov\u00fdch ostrov\u016f",
                "",
                "",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Severoz\u00e1padn\u00ed mexick\u00fd standardn\u00ed \u010das",
+        final String[] Volgograd = new String[] {
+               "Volgogradsk\u00fd standardn\u00ed \u010das",
                "",
-               "Severoz\u00e1padn\u00ed mexick\u00fd letn\u00ed \u010das",
+               "Volgogradsk\u00fd letn\u00ed \u010das",
                "",
-               "Severoz\u00e1padn\u00ed mexick\u00fd \u010das",
+               "Volgogradsk\u00fd \u010das",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "\u010cas Velikono\u010dn\u00edho ostrova",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Severoz\u00e1padn\u00ed mexick\u00fd standardn\u00ed \u010das",
+               "",
+               "Severoz\u00e1padn\u00ed mexick\u00fd letn\u00ed \u010das",
+               "",
+               "Severoz\u00e1padn\u00ed mexick\u00fd \u010das",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "\u010cas stanice Dumonta d\u2019Urvilla",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "Samarsk\u00fd \u010das",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "Pchjongjangsk\u00fd \u010das",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "Indick\u00fd \u010das",
                "",
@@ -1277,7 +1269,16 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1362,16 +1363,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST",
-                new String[] {
-                    "Havajsko-aleutsk\u00fd standardn\u00ed \u010das",
-                    "HST",
-                    "Havajsko-aleutsk\u00fd letn\u00ed \u010das",
-                    "HDT",
-                    "Havajsko-aleutsk\u00fd \u010das",
-                    "HST",
-                }
-            },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1481,12 +1472,12 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "New York" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
-            { "timezone.excity.Etc/Unknown", "Nezn\u00e1m\u00e9 m\u011bsto" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "timezone.excity.Etc/Unknown", "nezn\u00e1m\u00e9 m\u011bsto" },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Thule" },
             { "timezone.excity.America/Grand_Turk", "Grand Turk" },
             { "America/Yakutat", Alaska },
@@ -1547,8 +1538,17 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Svat\u00e1 Helena" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Lucemburk" },
             { "America/Cayman", America_Eastern },
@@ -1705,7 +1705,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
             { "timezone.excity.America/Eirunepe", "Eirunepe" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiaba" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1742,6 +1741,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanaj" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1913,7 +1913,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1938,7 +1938,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "Ath\u00e9ny" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1960,7 +1960,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Jeruzal\u00e9m" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Rij\u00e1d" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2132,7 +2132,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.America/St_Thomas", "Svat\u00fd Tom\u00e1\u0161 (Karibik)" },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "America/Rio_Branco", Acre },
@@ -2144,7 +2144,6 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Vladivostok", "Vladivostok" },
             { "Africa/Lusaka", Africa_Central },
             { "timezone.excity.Africa/Tunis", "Tunis" },
-            { "timezone.excity.Asia/Macau", "Macao" },
             { "America/Argentina/La_Rioja", Argentina },
             { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
