@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -318,14 +318,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m nan Eileanan F\u00e0clannach",
                "",
             };
-        final String[] Bhutan = new String[] {
-               "\u00c0m But\u00e0in",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Apia = new String[] {
                "Bun-\u00e0m Apia",
                "",
@@ -334,6 +326,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Apia",
                "",
             };
+        final String[] Bhutan = new String[] {
+               "\u00c0m But\u00e0in",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Nauru = new String[] {
                "\u00c0m Nabhru",
                "",
@@ -574,12 +574,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "Bun-\u00e0m Coloimbia",
+        final String[] Australia_Eastern = new String[] {
+               "Bun-\u00e0m Astr\u00e0ilia an Ear",
                "",
-               "T\u00ecde samhraidh Coloimbia",
+               "T\u00ecde samhraidh Astr\u00e0ilia an Ear",
                "",
-               "\u00c0m Coloimbia",
+               "\u00c0m Astr\u00e0ilia an Ear",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -590,12 +590,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "Bun-\u00e0m Astr\u00e0ilia an Ear",
+        final String[] Colombia = new String[] {
+               "Bun-\u00e0m Coloimbia",
                "",
-               "T\u00ecde samhraidh Astr\u00e0ilia an Ear",
+               "T\u00ecde samhraidh Coloimbia",
                "",
-               "\u00c0m Astr\u00e0ilia an Ear",
+               "\u00c0m Coloimbia",
                "",
             };
         final String[] Chile = new String[] {
@@ -710,14 +710,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Paraguaidh",
                "",
             };
-        final String[] Casey = new String[] {
-               "\u00c0m Chasey",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "\u00c0m Mhalaidhsea",
                "",
@@ -1062,12 +1054,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "Bun-\u00e0m Mheagsago an Iar-thuath",
+        final String[] Volgograd = new String[] {
+               "Bun-\u00e0m Volgograd",
                "",
-               "T\u00ecde samhraidh Mheagsago an Iar-thuath",
+               "T\u00ecde samhraidh Volgograd",
                "",
-               "\u00c0m Mheagsago an Iar-thuath",
+               "\u00c0m Volgograd",
                "",
             };
         final String[] Easter = new String[] {
@@ -1078,6 +1070,14 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Eilean na C\u00e0isge",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "Bun-\u00e0m Mheagsago an Iar-thuath",
+               "",
+               "T\u00ecde samhraidh Mheagsago an Iar-thuath",
+               "",
+               "\u00c0m Mheagsago an Iar-thuath",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "\u00c0m Dumont-d\u2019Urville",
                "",
@@ -1230,14 +1230,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                "\u00c0m Samara",
                "",
             };
-        final String[] Pyongyang = new String[] {
-               "\u00c0m Pyeongyang",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] India = new String[] {
                "\u00c0m nan Innseachan",
                "",
@@ -1277,7 +1269,16 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1359,16 +1360,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Antarctica/McMurdo", New_Zealand },
             { "timezone.excity.America/Nome", "Nome" },
             { "Pacific/Tahiti", Tahiti },
-            { "HST",
-                new String[] {
-                    "Bun-\u00e0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
-                    "HST",
-                    "T\u00ecde Samhraidh nan Eileanan Hawai\u2019i \u2019s Aleutach",
-                    "HDT",
-                    "\u00c0m nan Eileanan Hawai\u2019i \u2019s Aleutach",
-                    "HST",
-                }
-            },
             { "timezone.excity.America/Vancouver", "Vancouver" },
             { "timezone.excity.America/Matamoros", "Matamoros" },
             { "Africa/Asmera", Africa_Eastern },
@@ -1477,12 +1468,12 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Sao_Paulo", "S\u00e3o Paulo" },
             { "Pacific/Gambier", Gambier },
             { "Africa/Gaborone", Africa_Central },
-            { "Asia/Pyongyang", Pyongyang },
+            { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nuadh Eabhrac" },
             { "Asia/Gaza", Europe_Eastern },
             { "timezone.excity.Africa/Accra", "Accra" },
             { "timezone.excity.Etc/Unknown", "Baile neo-aithnichte" },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "timezone.excity.America/Thule", "Qaanaaq" },
             { "timezone.excity.America/Grand_Turk", "An Turc Mh\u00f2r" },
             { "America/Yakutat", Alaska },
@@ -1543,8 +1534,17 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Asia/Vladivostok", Vladivostok },
             { "timezone.excity.Atlantic/St_Helena", "Eilean Naomh Eilidh" },
             { "Africa/Maputo", Africa_Central },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
             { "timezone.excity.Europe/Luxembourg", "Lugsamburg" },
             { "America/Cayman", America_Eastern },
@@ -1701,7 +1701,6 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.America/Goose_Bay", "Goose Bay" },
             { "timezone.excity.America/Los_Angeles", "Los Angeles" },
             { "timezone.excity.America/Eirunepe", "Eirunep\u00e9" },
-            { "MST", America_Mountain },
             { "America/Whitehorse", America_Pacific },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "Pacific/Noumea", New_Caledonia },
@@ -1738,6 +1737,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Caracas", Venezuela },
             { "Asia/Hebron", Europe_Eastern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Qostana\u0131" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Louisville", "Louisville" },
@@ -1909,7 +1909,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "timezone.excity.America/Metlakatla", "Metlakatla" },
             { "Asia/Yakutsk", Yakutsk },
@@ -1934,7 +1934,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "timezone.excity.Europe/Athens", "An \u00c0ithne" },
             { "Africa/Djibouti", Africa_Eastern },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1956,7 +1956,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Jerusalem", "Ierusalam" },
             { "Atlantic/Faeroe", Europe_Western },
             { "timezone.excity.Asia/Riyadh", "Riyadh" },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -2126,7 +2126,7 @@ public class TimeZoneNames_gd extends TimeZoneNamesBundle {
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
             { "timezone.excity.Europe/Busingen", "Busingen" },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "timezone.excity.Europe/Istanbul", "Istanbul" },
             { "America/Rio_Branco", Acre },
