@@ -175,11 +175,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Eastern = new String[] {
-               "Hora padr\u00e3o Oriental",
+               "Hora padr\u00e3o oriental norte-americana",
                "",
-               "Hora de ver\u00e3o Oriental",
+               "Hora de ver\u00e3o oriental norte-americana",
                "",
-               "Hora Oriental",
+               "Hora oriental norte-americana",
                "",
             };
         final String[] Lord_Howe = new String[] {
@@ -463,11 +463,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Central = new String[] {
-               "Hora padr\u00e3o Central",
+               "Hora padr\u00e3o central norte-americana",
                "",
-               "Hora de ver\u00e3o Central",
+               "Hora de ver\u00e3o central norte-americana",
                "",
-               "Hora Central",
+               "Hora central norte-americana",
                "",
             };
         final String[] Truk = new String[] {
@@ -727,11 +727,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Pacific = new String[] {
-               "Hora padr\u00e3o do Pac\u00edfico",
+               "Hora padr\u00e3o do Pac\u00edfico norte-americana",
                "",
-               "Hora de ver\u00e3o do Pac\u00edfico",
+               "Hora de ver\u00e3o do Pac\u00edfico norte-americana",
                "",
-               "Hora do Pac\u00edfico",
+               "Hora do Pac\u00edfico norte-americana",
                "",
             };
         final String[] Phoenix_Islands = new String[] {
@@ -1095,11 +1095,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                "",
             };
         final String[] America_Mountain = new String[] {
-               "Hora padr\u00e3o da Montanha",
+               "Hora padr\u00e3o de montanha norte-americana",
                "",
-               "Hora de ver\u00e3o da Montanha",
+               "Hora de ver\u00e3o de montanha norte-americana",
                "",
-               "Hora da Montanha",
+               "Hora de montanha norte-americana",
                "",
             };
         final String[] Marquesas = new String[] {
@@ -1288,11 +1288,10 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Cuiaba", Amazon },
             { "timezone.excity.Europe/San_Marino", "S\u00e3o Marinho" },
             { "Africa/Nairobi", Africa_Eastern },
+            { "timezone.excity.Asia/Katmandu", "Catmandu" },
             { "America/Marigot", Atlantic },
             { "Asia/Aqtau", Kazakhstan_Western },
-            { "timezone.excity.Asia/Irkutsk", "Irkutsk" },
             { "Pacific/Kwajalein", Marshall_Islands },
-            { "timezone.excity.Pacific/Marquesas", "Marquesas" },
             { "America/El_Salvador", America_Central },
             { "Asia/Pontianak", Indonesia_Western },
             { "Africa/Cairo", Europe_Eastern },
@@ -1312,8 +1311,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "timezone.excity.Antarctica/Vostok", "Vostok" },
-            { "timezone.excity.Europe/Skopje", "Skopje" },
             { "America/Belize", America_Central },
             { "America/Panama", America_Eastern },
             { "America/Managua", America_Central },
@@ -1321,58 +1318,44 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Yerevan", Armenia },
             { "Europe/Brussels", Europe_Central },
             { "timezone.excity.Atlantic/Reykjavik", "Reiquiavique" },
-            { "timezone.excity.Pacific/Fiji", "Fiji" },
-            { "timezone.excity.Asia/Kamchatka", "Kamchatka" },
             { "Europe/Warsaw", Europe_Central },
             { "Pacific/Yap", Truk },
-            { "timezone.excity.Asia/Yakutsk", "Yakutsk" },
             { "timezone.excity.Africa/Djibouti", "Jibuti" },
             { "Europe/Jersey", GMT },
             { "America/Tegucigalpa", America_Central },
-            { "timezone.excity.Pacific/Wallis", "Wallis" },
             { "America/Eirunepe", Acre },
             { "America/Miquelon", Pierre_Miquelon },
             { "Europe/Luxembourg", Europe_Central },
             { "timezone.excity.Africa/Porto-Novo", "Porto-Novo" },
-            { "timezone.excity.Antarctica/Palmer", "Palmer" },
-            { "timezone.excity.Asia/Tashkent", "Tashkent" },
-            { "timezone.excity.Antarctica/Rothera", "Rothera" },
             { "Europe/Zaporozhye", Europe_Eastern },
             { "timezone.excity.Africa/Dakar", "Dacar" },
             { "Atlantic/St_Helena", GMT },
             { "timezone.excity.Africa/Addis_Ababa", "Adis-Abeba" },
             { "Europe/Guernsey", GMT },
-            { "timezone.excity.Pacific/Bougainville", "Bougainville" },
             { "America/Grand_Turk", America_Eastern },
             { "Asia/Samarkand", Uzbekistan },
-            { "timezone.excity.Europe/Tallinn", "Tallinn" },
-            { "timezone.excity.Pacific/Apia", "Apia" },
             { "Asia/Phnom_Penh", Indochina },
             { "Africa/Kigali", Africa_Central },
             { "Asia/Almaty", Kazakhstan_Eastern },
+            { "timezone.excity.America/El_Salvador", "Salvador" },
             { "Asia/Dubai", Gulf },
             { "Europe/Isle_of_Man", GMT },
             { "America/Araguaina", Brasilia },
             { "timezone.excity.Pacific/Easter", "Ilha da P\u00e1scoa" },
-            { "timezone.excity.Pacific/Guam", "Guam" },
             { "Asia/Novosibirsk", Novosibirsk },
-            { "timezone.excity.Europe/Vaduz", "Vaduz" },
             { "America/Argentina/Salta", Argentina },
             { "Africa/Tunis", Europe_Central },
             { "Pacific/Fakaofo", Tokelau },
             { "Africa/Tripoli", Europe_Eastern },
             { "Africa/Banjul", GMT },
             { "Indian/Comoro", Africa_Eastern },
-            { "timezone.excity.Pacific/Niue", "Niue" },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "timezone.excity.Australia/Lord_Howe", "Ilha de Lord Howe" },
             { "Antarctica/Syowa", Syowa },
             { "Indian/Reunion", Reunion },
             { "Pacific/Palau", Palau },
             { "Europe/Kaliningrad", Europe_Eastern },
-            { "timezone.excity.Asia/Magadan", "Magadan" },
             { "America/Montevideo", Uruguay },
-            { "timezone.excity.Pacific/Wake", "Wake" },
             { "Africa/Windhoek", Africa_Central },
             { "Asia/Karachi", Pakistan },
             { "Africa/Mogadishu", Africa_Eastern },
@@ -1382,7 +1365,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Chita", Yakutsk },
             { "Pacific/Easter", Easter },
             { "Antarctica/Davis", Davis },
-            { "timezone.excity.Asia/Krasnoyarsk", "Krasnoyarsk" },
             { "Antarctica/McMurdo", New_Zealand },
             { "America/Manaus", Amazon },
             { "Africa/Freetown", GMT },
@@ -1392,16 +1374,13 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Yerevan", "Erevan" },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
-            { "timezone.excity.Asia/Choibalsan", "Choibalsan" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "Africa/Malabo", Africa_Western },
             { "Europe/Skopje", Europe_Central },
             { "America/Catamarca", Argentina },
             { "America/Godthab", Greenland_Western },
             { "Europe/Sarajevo", Europe_Central },
-            { "timezone.excity.Asia/Novokuznetsk", "Novokuznetsk" },
             { "Africa/Lagos", Africa_Western },
-            { "timezone.excity.Pacific/Midway", "Midway" },
             { "America/Cordoba", Argentina },
             { "Europe/Rome", Europe_Central },
             { "Indian/Mauritius", Mauritius },
@@ -1413,7 +1392,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Zurich", Europe_Central },
             { "America/Anguilla", Atlantic },
             { "Asia/Dili", East_Timor },
-            { "timezone.excity.Australia/Perth", "Perth" },
             { "Africa/Bamako", GMT },
             { "Europe/Saratov",
                 new String[] {
@@ -1425,31 +1403,24 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "timezone.excity.Arctic/Longyearbyen", "Longyearbyen" },
             { "Pacific/Wallis", Wallis },
             { "Europe/Gibraltar", Europe_Central },
             { "Africa/Conakry", GMT },
             { "Africa/Lubumbashi", Africa_Central },
-            { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "America/Havana", Cuba },
             { "Asia/Choibalsan", Choibalsan },
             { "Asia/Omsk", Omsk },
             { "Europe/Vaduz", Europe_Central },
             { "Asia/Dhaka", Bangladesh },
             { "America/Barbados", Atlantic },
-            { "timezone.excity.Australia/Lindeman", "Lindeman" },
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "America/Louisville", America_Eastern },
-            { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
-            { "timezone.excity.Asia/Almaty", "Almaty" },
             { "Pacific/Johnston", Hawaii_Aleutian },
             { "Pacific/Chatham", Chatham },
             { "Europe/Ljubljana", Europe_Central },
             { "America/Sao_Paulo", Brasilia },
             { "Asia/Jayapura", Indonesia_Eastern },
-            { "timezone.excity.Europe/Andorra", "Andorra" },
-            { "timezone.excity.Europe/Minsk", "Minsk" },
             { "America/Curacao", Atlantic },
             { "Asia/Dushanbe", Tajikistan },
             { "America/Guyana", Guyana },
@@ -1465,7 +1436,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Europe/Stockholm", Europe_Central },
             { "Europe/Budapest", Europe_Central },
             { "Australia/Eucla", Australia_CentralWestern },
-            { "timezone.excity.Asia/Pontianak", "Pontianak" },
             { "Europe/Zagreb", Europe_Central },
             { "America/Port_of_Spain", Atlantic },
             { "Europe/Helsinki", Europe_Eastern },
@@ -1482,7 +1452,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                 }
             },
             { "timezone.excity.America/Montevideo", "Montevideu" },
-            { "timezone.excity.Pacific/Johnston", "Johnston" },
             { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
@@ -1494,36 +1463,28 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Indian/Maldives", Maldives },
             { "SystemV/AST4", Atlantic },
             { "timezone.excity.Europe/Madrid", "Madrid" },
-            { "timezone.excity.Europe/Simferopol", "Simferopol" },
             { "Asia/Oral", Kazakhstan_Western },
             { "America/Yellowknife", America_Mountain },
             { "Pacific/Enderbury", Phoenix_Islands },
             { "America/Juneau", Alaska },
-            { "timezone.excity.Indian/Kerguelen", "Kerguelen" },
             { "America/Indiana/Vevay", America_Eastern },
-            { "timezone.excity.Asia/Phnom_Penh", "Phnom Penh" },
             { "timezone.excity.Europe/Monaco", "M\u00f3naco" },
-            { "timezone.excity.Asia/Hebron", "Hebron" },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Jakarta", Indonesia_Western },
             { "Africa/Ceuta", Europe_Central },
-            { "timezone.excity.Antarctica/Mawson", "Mawson" },
+            { "timezone.excity.Asia/Karachi", "Carachi" },
             { "timezone.excity.Africa/Bamako", "Bamaco" },
             { "America/Recife", Brasilia },
             { "America/Buenos_Aires", Argentina },
             { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "America/Noronha", Noronha },
             { "America/Swift_Current", America_Central },
-            { "timezone.excity.Pacific/Enderbury", "Enderbury" },
-            { "timezone.excity.Asia/Pyongyang", "Pyongyang" },
-            { "timezone.excity.Australia/Hobart", "Hobart" },
             { "Australia/Adelaide", Australia_Central },
             { "America/Metlakatla", Alaska },
             { "Africa/Djibouti", Africa_Eastern },
             { "America/Paramaribo", Suriname },
             { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
-            { "timezone.excity.Asia/Bishkek", "Bishkek" },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
             { "Europe/Prague", Europe_Central },
@@ -1545,7 +1506,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Africa/Gaborone", Africa_Central },
             { "Asia/Pyongyang", Korea },
             { "timezone.excity.America/New_York", "Nova Iorque" },
-            { "timezone.excity.Australia/Darwin", "Darwin" },
             { "America/St_Vincent", Atlantic },
             { "Asia/Gaza", Europe_Eastern },
             { "PST8PDT", America_Pacific },
@@ -1557,14 +1517,8 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Lusaka", "Lusaca" },
             { "Atlantic/Azores", Azores },
             { "Europe/Vienna", Europe_Central },
-            { "timezone.excity.Antarctica/Macquarie", "Macquarie" },
-            { "timezone.excity.Asia/Ust-Nera", "Ust-Nera" },
-            { "timezone.excity.Europe/Uzhgorod", "Uzhgorod" },
             { "Pacific/Pitcairn", Pitcairn },
-            { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "America/Mazatlan", Mexico_Pacific },
-            { "timezone.excity.Asia/Baku", "Baku" },
-            { "timezone.excity.Asia/Hovd", "Hovd" },
             { "Pacific/Nauru", Nauru },
             { "Europe/Tirane", Europe_Central },
             { "SystemV/MST7", America_Mountain },
@@ -1577,7 +1531,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Tehran", "Teer\u00e3o" },
             { "America/Santarem", Brasilia },
             { "America/Asuncion", Paraguay },
-            { "timezone.excity.Asia/Khandyga", "Khandyga" },
             { "America/Boise", America_Mountain },
             { "Australia/Currie", Australia_Eastern },
             { "EST5EDT", America_Eastern },
@@ -1617,14 +1570,11 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Bishkek", Kyrgystan },
             { "Atlantic/Stanley", Falkland },
             { "SystemV/CST6", America_Central },
-            { "timezone.excity.Asia/Calcutta", "Calcut\u00e1" },
             { "Indian/Mahe", Seychelles },
             { "Asia/Aqtobe", Kazakhstan_Western },
             { "timezone.excity.Pacific/Efate", "Efate" },
-            { "timezone.excity.Asia/Gaza", "Gaza" },
             { "timezone.excity.Asia/Aqtobe", "Aqtobe" },
             { "Asia/Vladivostok", Vladivostok },
-            { "timezone.excity.Africa/Ceuta", "Ceuta" },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Maputo", Africa_Central },
             { "America/Kentucky/Monticello", America_Eastern },
@@ -1641,32 +1591,24 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "timezone.excity.Pacific/Rarotonga", "Rarotonga" },
-            { "timezone.excity.Antarctica/Troll", "Troll" },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Cayman", America_Eastern },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Baghdad", Arabian },
             { "timezone.excity.Asia/Bahrain", "Bar\u00e9m" },
-            { "timezone.excity.Asia/Hong_Kong", "Hong Kong" },
             { "timezone.excity.Indian/Mahe", "Mahe" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "Europe/San_Marino", Europe_Central },
             { "America/Indiana/Tell_City", America_Central },
             { "America/Tijuana", America_Pacific },
-            { "timezone.excity.Australia/Eucla", "Eucla" },
-            { "timezone.excity.Pacific/Kwajalein", "Kwajalein" },
             { "Pacific/Saipan", Chamorro },
             { "SystemV/YST9", Gambier },
             { "timezone.excity.America/Curacao", "Cura\u00e7au" },
-            { "timezone.excity.Pacific/Nauru", "Nauru" },
             { "Africa/Douala", Africa_Western },
             { "America/Chihuahua", Mexico_Pacific },
             { "America/Ojinaga", America_Mountain },
             { "Asia/Hovd", Hovd },
-            { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
-            { "timezone.excity.Pacific/Gambier", "Gambier" },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Damascus", Europe_Eastern },
             { "America/Argentina/San_Luis", Argentina_Western },
@@ -1701,10 +1643,7 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.America/Port_of_Spain", "Porto de Espanha" },
             { "Africa/Addis_Ababa", Africa_Eastern },
             { "Europe/Uzhgorod", Europe_Eastern },
-            { "timezone.excity.Asia/Chita", "Chita" },
-            { "timezone.excity.Asia/Colombo", "Colombo" },
             { "America/Indiana/Marengo", America_Eastern },
-            { "timezone.excity.Pacific/Port_Moresby", "Port Moresby" },
             { "America/Creston", America_Mountain },
             { "America/Punta_Arenas",
                 new String[] {
@@ -1720,8 +1659,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Mexico_City", America_Central },
             { "Antarctica/Vostok", Vostok },
             { "Europe/Andorra", Europe_Central },
-            { "timezone.excity.Asia/Anadyr", "Anadyr" },
-            { "timezone.excity.Asia/Urumqi", "Urumqi" },
             { "Asia/Vientiane", Indochina },
             { "Pacific/Kiritimati", Line_Islands },
             { "America/Matamoros", America_Central },
@@ -1733,7 +1670,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Asia/Harbin", China },
             { "Europe/Oslo", Europe_Central },
             { "Asia/Novokuznetsk", Krasnoyarsk },
-            { "timezone.excity.Asia/Jayapura", "Jayapura" },
             { "timezone.excity.America/Bahia_Banderas", "Bahia Banderas" },
             { "CST6CDT", America_Central },
             { "Atlantic/Canary", Europe_Western },
@@ -1743,24 +1679,19 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Africa/Lome", GMT },
             { "America/Bogota", Colombia },
             { "America/Menominee", America_Central },
-            { "timezone.excity.Pacific/Guadalcanal", "Guadalcanal" },
             { "America/Adak", Hawaii_Aleutian },
             { "Pacific/Norfolk", Norfolk },
             { "America/Resolute", America_Central },
             { "Pacific/Tarawa", Gilbert_Islands },
-            { "timezone.excity.Australia/Sydney", "Sydney" },
-            { "timezone.excity.Asia/Qatar", "Catar" },
             { "Africa/Kampala", Africa_Eastern },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
             { "timezone.excity.Asia/Kuwait", "Koweit" },
             { "SystemV/EST5", America_Eastern },
-            { "timezone.excity.Antarctica/Davis", "Davis" },
             { "America/Edmonton", America_Mountain },
             { "Europe/Podgorica", Europe_Central },
             { "timezone.excity.Europe/Moscow", "Moscovo" },
             { "Africa/Bujumbura", Africa_Central },
             { "America/Santo_Domingo", Atlantic },
-            { "timezone.excity.Asia/Qyzylorda", "Qyzylorda" },
             { "Europe/Minsk", Moscow },
             { "Pacific/Auckland", New_Zealand },
             { "America/Glace_Bay", Atlantic },
@@ -1786,17 +1717,14 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "timezone.excity.Asia/Dhaka", "Daca" },
             { "Africa/Luanda", Africa_Western },
             { "America/Nipigon", America_Eastern },
-            { "timezone.excity.Europe/Mariehamn", "Mariehamn" },
             { "timezone.excity.America/St_Johns", "St. John\u2019s" },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Asia/Muscat", Gulf },
             { "Asia/Bahrain", Arabian },
             { "Europe/Vilnius", Europe_Eastern },
-            { "timezone.excity.Asia/Oral", "Oral" },
             { "America/Fortaleza", Brasilia },
             { "America/Hermosillo", Mexico_Pacific },
             { "America/Cancun", America_Eastern },
-            { "timezone.excity.Asia/Manila", "Manila" },
             { "Africa/Maseru", Africa_Southern },
             { "Pacific/Kosrae", Kosrae },
             { "Africa/Kinshasa", Africa_Western },
@@ -1825,7 +1753,6 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "America/Detroit", America_Eastern },
             { "timezone.excity.Africa/Ndjamena", "Ndjamena" },
             { "America/Thule", Atlantic },
-            { "timezone.excity.Asia/Vladivostok", "Vladivostok" },
             { "Africa/Lusaka", Africa_Central },
             { "Asia/Hong_Kong", Hong_Kong },
             { "timezone.excity.Africa/Tunis", "Tunes" },
@@ -1833,27 +1760,20 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Africa/Dakar", GMT },
             { "SystemV/CST6CDT", America_Central },
             { "America/Tortola", Atlantic },
-            { "timezone.excity.Antarctica/McMurdo", "McMurdo" },
             { "America/Porto_Velho", Amazon },
             { "Asia/Sakhalin", Sakhalin },
             { "America/Scoresbysund", Greenland_Eastern },
-            { "timezone.excity.Asia/Novosibirsk", "Novosibirsk" },
             { "Asia/Kamchatka", Kamchatka },
             { "Africa/Harare", Africa_Central },
-            { "timezone.excity.Asia/Srednekolymsk", "Srednekolymsk" },
             { "America/Nome", Alaska },
             { "timezone.excity.Africa/Nairobi", "Nairobi" },
             { "Europe/Tallinn", Europe_Eastern },
             { "Africa/Khartoum", Africa_Central },
             { "Africa/Johannesburg", Africa_Southern },
-            { "timezone.excity.Pacific/Fakaofo", "Fakaofo" },
             { "Africa/Bangui", Africa_Western },
-            { "timezone.excity.Australia/Adelaide", "Adelaide" },
-            { "timezone.excity.Asia/Singapore", "Singapura" },
             { "Europe/Belgrade", Europe_Central },
             { "Africa/Bissau", GMT },
             { "timezone.excity.America/Cayman", "Caim\u00e3o" },
-            { "timezone.excity.Europe/Bratislava", "Bratislava" },
             { "Asia/Tehran", Iran },
             { "Europe/Astrakhan",
                 new String[] {
@@ -1865,44 +1785,29 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "timezone.excity.Asia/Dili", "Dili" },
-            { "timezone.excity.Asia/Omsk", "Omsk" },
             { "Africa/Juba", Africa_Eastern },
             { "America/Campo_Grande", Amazon },
             { "America/Belem", Brasilia },
             { "Asia/Saigon", Indochina },
             { "Pacific/Midway", Samoa },
             { "America/Jujuy", Argentina },
-            { "timezone.excity.Asia/Brunei", "Brunei" },
             { "timezone.excity.Atlantic/Faeroe", "Faro\u00e9" },
             { "Africa/Timbuktu", GMT },
             { "America/Bahia", Brasilia },
             { "America/Goose_Bay", Atlantic },
-            { "timezone.excity.Asia/Kuching", "Kuching" },
-            { "timezone.excity.Antarctica/Casey", "Casey" },
             { "America/Pangnirtung", America_Eastern },
-            { "timezone.excity.Pacific/Palau", "Palau" },
             { "Asia/Katmandu", Nepal },
-            { "timezone.excity.Pacific/Auckland", "Auckland" },
             { "Africa/Niamey", Africa_Western },
             { "America/Whitehorse", America_Pacific },
             { "Pacific/Noumea", New_Caledonia },
-            { "timezone.excity.Pacific/Norfolk", "Norfolk" },
             { "Asia/Tbilisi", Georgia },
-            { "timezone.excity.Australia/Melbourne", "Melbourne" },
             { "America/Montreal", America_Eastern },
-            { "timezone.excity.America/Anguilla", "Anguila" },
-            { "timezone.excity.Pacific/Tongatapu", "Tongatapu" },
             { "Asia/Makassar", Indonesia_Central },
             { "America/Argentina/San_Juan", Argentina },
-            { "timezone.excity.Antarctica/Syowa", "Syowa" },
-            { "timezone.excity.Pacific/Funafuti", "Funafuti" },
-            { "timezone.excity.Europe/Podgorica", "Podgorica" },
             { "Asia/Nicosia", Europe_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
-            { "timezone.excity.Australia/Brisbane", "Brisbane" },
             { "SystemV/MST7MDT", America_Mountain },
-            { "timezone.excity.Asia/Vientiane", "Vientiane" },
+            { "timezone.excity.Asia/Aden", "Adem" },
             { "America/Boa_Vista", Amazon },
             { "America/Grenada", Atlantic },
             { "Asia/Atyrau", Kazakhstan_Western },
@@ -1929,7 +1834,9 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             { "Indian/Cocos", Cocos },
             { "Pacific/Tongatapu", Tonga },
             { "timezone.excity.Asia/Aqtau", "Aqtau" },
+            { "timezone.excity.Asia/Rangoon", "Yangon" },
             { "SystemV/YST9YDT", Alaska },
+            { "timezone.excity.Asia/Thimphu", "Timphu" },
             { "Europe/Ulyanovsk",
                 new String[] {
                     "",
@@ -1942,19 +1849,17 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             },
             { "America/Merida", America_Central },
             { "America/St_Kitts", Atlantic },
-            { "timezone.excity.Asia/Dubai", "Dubai" },
             { "Arctic/Longyearbyen", Europe_Central },
-            { "timezone.excity.Asia/Kuala_Lumpur", "Kuala Lumpur" },
             { "America/Fort_Nelson", America_Mountain },
             { "America/Caracas", Venezuela },
             { "America/Guadeloupe", Atlantic },
             { "Asia/Hebron", Europe_Eastern },
             { "Indian/Kerguelen", French_Southern },
             { "SystemV/PST8PDT", America_Pacific },
+            { "timezone.excity.Asia/Qostanay", "Kostanay" },
             { "Africa/Monrovia", GMT },
             { "Asia/Ust-Nera", Vladivostok },
             { "timezone.excity.America/Cancun", "Cancun" },
-            { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
             { "timezone.excity.Europe/Kaliningrad", "Caliningrado" },
             { "Asia/Srednekolymsk",
                 new String[] {
@@ -1968,20 +1873,15 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
             },
             { "America/North_Dakota/New_Salem", America_Central },
             { "Asia/Anadyr", Anadyr },
-            { "timezone.excity.Pacific/Kiritimati", "Kiritimati" },
             { "Australia/Melbourne", Australia_Eastern },
             { "Asia/Irkutsk", Irkutsk },
-            { "timezone.excity.Indian/Chagos", "Chagos" },
-            { "timezone.excity.Asia/Kabul", "Cabul" },
             { "America/Shiprock", America_Mountain },
             { "America/Winnipeg", America_Central },
             { "timezone.excity.Pacific/Tarawa", "Tarawa" },
             { "timezone.excity.Europe/Amsterdam", "Amesterd\u00e3o" },
-            { "timezone.excity.Pacific/Saipan", "Saipan" },
             { "Europe/Vatican", Europe_Central },
             { "timezone.excity.Indian/Cocos", "Ilhas Cocos" },
             { "Asia/Amman", Europe_Eastern },
-            { "timezone.excity.Australia/Currie", "Currie" },
             { "Etc/UTC",
                 new String[] {
                     "Hora Coordenada Universal",
@@ -1993,16 +1893,13 @@ public class TimeZoneNames_pt_PT extends TimeZoneNamesBundle {
                 }
             },
             { "SystemV/AST4ADT", Atlantic },
-            { "timezone.excity.Europe/Chisinau", "Chisinau" },
             { "America/Toronto", America_Eastern },
             { "Asia/Singapore", Singapore },
             { "Australia/Lindeman", Australia_Eastern },
             { "SystemV/EST5EDT", America_Eastern },
             { "Pacific/Majuro", Marshall_Islands },
-            { "timezone.excity.Europe/Samara", "Samara" },
             { "Pacific/Guadalcanal", Solomon },
             { "Europe/Athens", Europe_Eastern },
-            { "timezone.excity.Europe/Vilnius", "Vilnius" },
             { "Europe/Monaco", Europe_Central },
         };
         return data;
