@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -166,14 +166,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "\u0626\u0627\u0643\u0631\u06d0 \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
-        final String[] Casey = new String[] {
-               "\u0643\u0627\u0633\u06d0\u064a \u06cb\u0627\u0642\u062a\u0649",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Malaysia = new String[] {
                "\u0645\u0627\u0644\u0627\u064a\u0634\u0649\u064a\u0627 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -902,6 +894,14 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "\u064a\u06d0\u06ad\u0649 \u0643\u0627\u0644\u06d0\u062f\u0648\u0646\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
+        final String[] Volgograd = new String[] {
+               "\u06cb\u0648\u0644\u06af\u0627\u06af\u0631\u0627\u062f \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
+               "",
+               "\u06cb\u0648\u0644\u06af\u0627\u06af\u0631\u0627\u062f \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+               "",
+               "\u06cb\u0648\u0644\u06af\u0627\u06af\u0631\u0627\u062f \u06cb\u0627\u0642\u062a\u0649",
+               "",
+            };
         final String[] Brunei = new String[] {
                "\u0628\u0649\u0631\u06c7\u0646\u0649\u064a \u062f\u0627\u0631\u06c7\u0633\u0633\u0627\u0644\u0627\u0645 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -918,14 +918,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "\u0626\u0649\u0631\u0627\u0646 \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
-        final String[] Mexico_Northwest = new String[] {
-               "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u063a\u06d5\u0631\u0628\u0649\u064a \u0634\u0649\u0645\u0627\u0644\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
-               "",
-               "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u063a\u06d5\u0631\u0628\u0649\u064a \u0634\u0649\u0645\u0627\u0644\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
-               "",
-               "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u063a\u06d5\u0631\u0628\u0649\u064a \u0634\u0649\u0645\u0627\u0644\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
-               "",
-            };
         final String[] Easter = new String[] {
                "\u067e\u0627\u0633\u0643\u0627\u0644\u064a\u0627 \u0626\u0627\u0631\u0649\u0644\u0649 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -934,6 +926,14 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "\u0626\u06d0\u0633\u062a\u06d0\u0631 \u0626\u0627\u0631\u0649\u0644\u0649 \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
+        final String[] Mexico_Northwest = new String[] {
+               "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u063a\u06d5\u0631\u0628\u0649\u064a \u0634\u0649\u0645\u0627\u0644\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
+               "",
+               "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u063a\u06d5\u0631\u0628\u0649\u064a \u0634\u0649\u0645\u0627\u0644\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+               "",
+               "\u0645\u06d0\u0643\u0633\u0649\u0643\u0627 \u063a\u06d5\u0631\u0628\u0649\u064a \u0634\u0649\u0645\u0627\u0644\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
+               "",
+            };
         final String[] DumontDUrville = new String[] {
                "\u062f\u06c7\u0645\u0648\u0646\u062a-\u062f\u06c7\u0631\u06cb\u0649\u0644 \u06cb\u0627\u0642\u062a\u0649",
                "",
@@ -1046,12 +1046,12 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Colombia = new String[] {
-               "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
+        final String[] Australia_Eastern = new String[] {
+               "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
                "",
-               "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+               "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
                "",
-               "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
+               "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
         final String[] French_Guiana = new String[] {
@@ -1062,12 +1062,12 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Australia_Eastern = new String[] {
-               "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
+        final String[] Colombia = new String[] {
+               "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u0626\u06c6\u0644\u0686\u06d5\u0645\u0644\u0649\u0643 \u06cb\u0627\u0642\u062a\u0649",
                "",
-               "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
+               "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u064a\u0627\u0632\u0644\u0649\u0642 \u06cb\u0627\u0642\u062a\u0649",
                "",
-               "\u0626\u0627\u06cb\u0633\u062a\u0631\u0627\u0644\u0649\u064a\u06d5 \u0634\u06d5\u0631\u0642\u0649\u064a \u0642\u0649\u0633\u0649\u0645 \u06cb\u0627\u0642\u062a\u0649",
+               "\u0643\u0648\u0644\u0648\u0645\u0628\u0649\u064a\u06d5 \u06cb\u0627\u0642\u062a\u0649",
                "",
             };
         final String[] Chile = new String[] {
@@ -1252,7 +1252,16 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/St_Johns", Newfoundland },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
-            { "Africa/Casablanca", Europe_Western },
+            { "Africa/Casablanca",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "Asia/Jerusalem", Israel },
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
@@ -1343,7 +1352,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Europe/Malta", Europe_Central },
             { "Pacific/Tahiti", Tahiti },
-            { "HST", Hawaii_Aleutian },
             { "Africa/Asmera", Africa_Eastern },
             { "Europe/Busingen", Europe_Central },
             { "America/Argentina/Rio_Gallegos", Argentina },
@@ -1423,7 +1431,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
                     "",
                 }
             },
-            { "Africa/Sao_Tome", Africa_Western },
+            { "Africa/Sao_Tome", GMT },
             { "Indian/Chagos", Indian_Ocean },
             { "America/Cayenne", French_Guiana },
             { "Asia/Yakutsk", Yakutsk },
@@ -1449,7 +1457,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "Africa/Djibouti", Africa_Eastern },
             { "America/Paramaribo", Suriname },
-            { "EST", America_Eastern },
+            { "Asia/Qostanay", Kazakhstan_Eastern },
             { "Europe/Simferopol", Moscow },
             { "Europe/Sofia", Europe_Eastern },
             { "Africa/Nouakchott", GMT },
@@ -1468,14 +1476,15 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Macquarie },
             { "America/Moncton", Atlantic },
             { "Africa/Gaborone", Africa_Central },
+            { "Asia/Pyongyang", Korea },
             { "America/St_Vincent", Atlantic },
             { "Asia/Gaza", Europe_Eastern },
             { "PST8PDT", America_Pacific },
             { "timezone.excity.Etc/Unknown", "\u064a\u0648\u0686\u06c7\u0646 \u0634\u06d5\u06be\u06d5\u0631" },
             { "Atlantic/Faeroe", Europe_Western },
-            { "Asia/Qyzylorda", Kazakhstan_Eastern },
+            { "Asia/Qyzylorda", Kazakhstan_Western },
             { "America/Yakutat", Alaska },
-            { "Antarctica/Casey", Casey },
+            { "Antarctica/Casey", Australia_Western },
             { "Europe/Copenhagen", Europe_Central },
             { "Atlantic/Azores", Azores },
             { "Europe/Vienna", Europe_Central },
@@ -1532,10 +1541,19 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Africa/Libreville", Africa_Western },
             { "Africa/Maputo", Africa_Central },
             { "America/Kentucky/Monticello", America_Eastern },
-            { "Africa/El_Aaiun", Europe_Western },
             { "Africa/Ouagadougou", GMT },
             { "America/Coral_Harbour", America_Eastern },
             { "Pacific/Marquesas", Marquesas },
+            { "Africa/El_Aaiun",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                    "",
+                }
+            },
             { "America/Aruba", Atlantic },
             { "America/North_Dakota/Center", America_Central },
             { "America/Cayman", America_Eastern },
@@ -1672,7 +1690,7 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "Indian/Antananarivo", Africa_Eastern },
             { "Australia/Brisbane", Australia_Eastern },
             { "Indian/Mayotte", Africa_Eastern },
-            { "Europe/Volgograd", Moscow },
+            { "Europe/Volgograd", Volgograd },
             { "America/Lower_Princes", Atlantic },
             { "America/Vancouver", America_Pacific },
             { "Africa/Blantyre", Africa_Central },
@@ -1720,7 +1738,6 @@ public class TimeZoneNames_ug extends TimeZoneNamesBundle {
             { "America/Goose_Bay", Atlantic },
             { "America/Pangnirtung", America_Eastern },
             { "Asia/Katmandu", Nepal },
-            { "MST", America_Mountain },
             { "Africa/Niamey", Africa_Western },
             { "America/Whitehorse", America_Pacific },
             { "Pacific/Noumea", New_Caledonia },
